'use strict';

/* For ESLint: List any global identifiers used in this file below */
/* global translate, BGcall, changeTextDirection, bindEnterClickToDefault,
parseUri, mayOpenDialogUI:true */
/* eslint-disable no-use-before-define */

// Global lock so we can't open more than once on a tab.
let mayOpenDialogUI;
if (typeof mayOpenDialogUI === 'undefined') {
  mayOpenDialogUI = true;
}

function topOpenWhitelistUI() {
  if (!mayOpenDialogUI) {
    return;
  }

  mayOpenDialogUI = false;

  const domain = document.location.host;

  // Get Flash objects out of the way of our UI
  BGcall('emitPageBroadcast', { fn: 'sendContentToBack', options: {} });

  // check if we're running on website with a frameset, if so, tell
  // the user we can't run on it.
  if ($('frameset').length >= 1) {
    // eslint-disable-next-line no-alert
    alert(translate('wizardcantrunonframesets'));
    mayOpenDialogUI = true;
    $('.adblock-ui-stylesheet').remove();
    return;
  }

  const btns = {};
  const adblockDefaultButtonText = translate('buttonexclude');
  btns[adblockDefaultButtonText] = {
    text: adblockDefaultButtonText,
    class: 'adblock_default_button',
    click() {
      const filter = `@@||${generateUrl()}$document`;
      BGcall('addCustomFilter', filter, () => {
        if ($('#reload_page').is(':checked')) {
          document.location.reload();
        } else {
          mayOpenDialogUI = true;
          $('.adblock-ui-stylesheet').remove();
          page.remove();
        }
      });
    },
  };
  btns[translate('buttoncancel')] = function closeDialog() {
    page.dialog('close');
  };

  const page = $('<div>')
    .append($('<span>').text(translate('adblock_wont_run_on_pages_matching')))
    .append('<br/><br/><i id="domainpart"></i><i id="pathpart"></i>')
    .append('<br/><br/><br/>')
    .append($('<span id="whitelister_dirs">').text(translate('you_can_slide_to_change')))
    .append('<br/>')
    .append($('<span id="modifydomain">').text(translate('modifydomain'))
      .append('<input id="domainslider" type="range" min="0" value="0">'))
    .append($('<span id="modifypath">').text(translate('modifypath'))
      .append('<input id="pathslider" type="range" min="0" value="0">'))
    .append('<br/><input type="checkbox" id="reload_page" checked/>')
    .append($('<label style="display: inline;" for="reload_page">').text(translate('reloadpageafterwhitelist')))
    .dialog({
      title: translate('whitelistertitle2'),
      classes: {
        'ui-dialog': 'adblock-whitelist-dialog',
      },
      closeText: '',
      position: { my: 'left top', at: 'left+10% top+10%', of: window },
      width: 600,
      minHeight: 130,
      buttons: btns,
      close() {
        mayOpenDialogUI = true;
        $('.adblock-ui-stylesheet').remove();
        page.remove();
      },
    });

  changeTextDirection($('body .adblock-whitelist-dialog'));

  const fixedDomainPart = parseUri.secondLevelDomainOnly(domain, true);
  const domainparts = domain.substr(0, domain.lastIndexOf(fixedDomainPart)).split('.');
  domainparts.splice(domainparts.length - 1, 1, fixedDomainPart);

  const location = document.location.pathname.match(/(.*?)(\/?)(\?|$)/);
  const pathparts = location[1].split('/');

  // Don't show the domain slider on
  // - sites without a third level domain name (e.g. foo.com)
  // - sites with an ip domain (e.g. 1.2.3.4)
  // Don't show the location slider on domain-only locations
  const noThirdLevelDomain = (domainparts.length === 1);
  const domainIsIp = /^(\d+\.){3}\d+$/.test(domain);
  const showDomain = !(noThirdLevelDomain || domainIsIp);
  $('#modifydomain', page).toggle(showDomain);
  const showPath = !!(location[1]);
  $('#modifypath', page).toggle(showPath);
  $('#whitelister_dirs', page).toggle(showDomain || showPath);

  // Generate the URL. If forDisplay is true, then it will truncate long URLs
  function generateUrl(forDisplay) {
    let result = '';
    const domainsliderValue = $('#domainslider', page)[0].valueAsNumber;
    const pathsliderValue = $('#pathslider', page)[0].valueAsNumber;

    // Make clear that it includes subdomains
    if (forDisplay && domainsliderValue !== 0) {
      result = '*.';
    }

    // Append the chosen parts of a domain
    for (let i = domainsliderValue; i <= (domainparts.length - 2); i += 1) {
      result += `${domainparts[i]}.`;
    }
    result += domainparts[domainparts.length - 1];
    for (let i = 1; i <= pathsliderValue; i += 1) {
      result += `/${pathparts[i]}`;
    }

    // Append a final slash for for example filehippo.com/download_dropbox/
    if (pathparts.length !== pathsliderValue + 1 || !location[1]) {
      result += '/';
      if (forDisplay) {
        result += '*';
      }
    } else if (location[2]) {
      result += location[2];
    }

    if (forDisplay) {
      result = result.replace(/(\/[^/]{6})[^/]{3,}([^/]{6})/g, '$1...$2');
      if (result.indexOf('/') > 30 && result.length >= 60) {
        result = result.replace(/^([^/]{20})[^/]+([^/]{6}\/)/, '$1...$2');
      }
      while (result.length >= 60) {
        result = result.replace(/(\/.{4}).*?\/.*?(.{4})(?:\/|$)/, '$1...$2/');
      }
      const domainpart = result.match(/^[^/]+/)[0];
      const pathpart = result.match(/\/.*$/)[0];
      $('#domainpart', page).text(domainpart);
      $('#pathpart', page).text(pathpart);
    } else {
      return result;
    }

    return undefined;
  }

  function onSliderChange() {
    generateUrl(true);
  }

  $('#domainslider', page)
    .attr('max', Math.max(domainparts.length - 1, 1));
  $('#pathslider', page)
    .attr('max', Math.max(pathparts.length - 1, 1));
  $('#pathslider, #domainslider', page)
    .on('input change', () => {
      onSliderChange();
    });

  onSliderChange();

  bindEnterClickToDefault();
}

// required return value for tabs.executeScript
/* eslint-disable-next-line no-unused-expressions */
'';

// # sourceURL=/uiscripts/topOpenWhitelistUI.js
